| NelPlo | R Documentation |
These are the extended Nelson-Plosser Data.
data(NelPlo)
14 macroeconomic time series: cpi, ip, gnp.nom,
vel, emp, int.rate, nom.wages,
gnp.def, money.stock, gnp.real,
stock.prices, gnp.capita, real.wages, and
unemp and the joint series NelPlo.
The series are of various lengths but all end in 1988. The data set contains the following series: consumer price index, industrial production, nominal GNP, velocity, employment, interest rate, nominal wages, GNP deflator, money stock, real GNP, stock prices (S&P500), GNP per capita, real wages, unemployment.
Nelson+Plosser:1982
Formerly in the Journal of Business and Economic Statistics data archive, currently at http://korora.econ.yale.edu/phillips/data/np&enp.dat.
Koop+Steel:1994
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.