Learn R Programming

tseries (version 0.10-61)

seqplot.ts: Plot Two Time Series

Description

Plot two time series on the same plot frame.

Usage

seqplot.ts(x, y, colx = "black", coly = "red", typex = "l",
           typey = "l", pchx = 1, pchy = 1, ltyx = "solid",
           ltyy = "solid", oma = c(6, 0, 5, 0), ann = par("ann"),
           xlab = "Time", ylab = deparse(substitute(x)), main = NULL)

Arguments

Value

None.

Details

Unlike plot.ts the series can have different time bases, but they should have the same frequency. Unlike ts.plot the series can be plotted in different styles and for multivariate x and y the common variables are plotted together in a separate array element.

See Also

Examples

Run this code
data(USeconomic)
x <- ts.union(log(M1), log(GNP), rs, rl)
m.ar <- ar(x, method = "ols", order.max = 5)
y <- predict(m.ar, x, n.ahead = 200, se.fit = FALSE)
seqplot.ts(x, y)

Run the code above in your browser using DataLab