Learn R Programming

tseries (version 0.10-61)

summary.garch: Summarizing GARCH Model Fits

Description

Methods for creating and printing summaries of GARCH model fits.

Usage

# S3 method for garch
summary(object, ...)
# S3 method for summary.garch
print(x, digits = max(3, getOption("digits") - 3),
      signif.stars = getOption("show.signif.stars"), ...)

Arguments

Value

A list of class "summary.garch".

Details

summary computes the asymptotic standard errors of the coefficient estimates from an outer-product approximation of the Hessian evaluated at the estimates, see Bollerslev:1986. It furthermore tests the residuals for normality and remaining ARCH effects, see jarque.bera.test and Box.test.

References

Bollerslev:1986

See Also

garch